@@ -15,7 +15,7 @@ macro_rules! declare_xlink_attributes {
             $(#[$attr])*
             #[inline]
             #[allow(non_snake_case)]
-            pub fn $name<V, MSG>(v: V) -> crate::Attribute<MSG>
+            pub fn $name<V, MSG>(v: V) -> crate::vdom::Attribute<MSG>
                 where V: Into<Value>,
                 {
                     attr_ns(Some(XLINK_NAMESPACE), $attribute, AttributeValue::from_value(v.into()))
