@@ -3,8 +3,12 @@
 //!
 use crate::html::attributes::{self, AttributeValue};
 use crate::Event;
+pub use leaf::Leaf;
+pub use node_trait::NodeTrait;
 
+pub mod leaf;
 pub(crate) mod map_msg;
+mod node_trait;
 
 /// namespace type in node, which could be change to an enum
 pub type Namespace = &'static str;
@@ -17,16 +21,16 @@ pub type AttributeName = &'static str;
 /// which is a &'static str. The missing type is now only MSG which will be supplied by the users
 /// App code.
 pub type Node<MSG> =
-    mt_dom::Node<Namespace, Tag, AttributeName, AttributeValue<MSG>>;
+    mt_dom::Node<Namespace, Tag, Leaf, AttributeName, AttributeValue<MSG>>;
 
 /// Element type with tag and attribute name type set to &'static str
 pub type Element<MSG> =
-    mt_dom::Element<Namespace, Tag, AttributeName, AttributeValue<MSG>>;
+    mt_dom::Element<Namespace, Tag, Leaf, AttributeName, AttributeValue<MSG>>;
 
 /// Patch as result of diffing the current_vdom and the new vdom.
 /// The tag and attribute name types is set to &'static str
 pub type Patch<'a, MSG> =
-    mt_dom::Patch<'a, Namespace, Tag, AttributeName, AttributeValue<MSG>>;
+    mt_dom::Patch<'a, Namespace, Tag, Leaf, AttributeName, AttributeValue<MSG>>;
 
 /// Attribute type used in sauron where the type of the Attribute name is &'static str
 pub type Attribute<MSG> =
@@ -46,7 +50,7 @@ where
     MSG: 'static,
 {
     use crate::html::attributes::Special;
-    use crate::map_msg::NodeMapMsg;
+    use map_msg::NodeMapMsg;
 
     // check if the skip attribute is true
     // if it is true, skip diffing and no patches is created at this dom
